@@ -7,6 +7,8 @@ from unittest.mock import patch
 import pytest
 
 from faker.providers.company.az_AZ import Provider as AzAzCompanyProvider
+from faker.providers.company.de_AT import Provider as DeAtCompanyProvider
+from faker.providers.company.de_CH import Provider as DeChCompanyProvider
 from faker.providers.company.el_GR import Provider as ElGrCompanyProvider
 from faker.providers.company.en_PH import Provider as EnPhCompanyProvider
 from faker.providers.company.es_ES import Provider as EsEsCompanyProvider
@@ -15,14 +17,19 @@ from faker.providers.company.hu_HU import Provider as HuHuCompanyProvider
 from faker.providers.company.hy_AM import Provider as HyAmCompanyProvider
 from faker.providers.company.it_IT import Provider as ItItCompanyProvider
 from faker.providers.company.ja_JP import Provider as JaJpCompanyProvider
+from faker.providers.company.ko_KR import Provider as KoKrCompanyProvider
 from faker.providers.company.nl_BE import Provider as NlBeCompanyProvider
 from faker.providers.company.nl_NL import Provider as NlNlCompanyProvider
 from faker.providers.company.pl_PL import Provider as PlPlCompanyProvider
-from faker.providers.company.pl_PL import company_vat_checksum, local_regon_checksum, regon_checksum
+from faker.providers.company.pl_PL import (
+    company_vat_checksum,
+    local_regon_checksum,
+    regon_checksum,
+)
 from faker.providers.company.pt_BR import company_id_checksum
 from faker.providers.company.ro_RO import Provider as RoRoCompanyProvider
 from faker.providers.company.ru_RU import Provider as RuRuCompanyProvider
-from faker.providers.company.ru_RU import calculate_checksum
+from faker.providers.company.ru_RU import calculate_checksum, calculate_snils_checksum
 from faker.providers.company.th_TH import Provider as ThThCompanyProvider
 from faker.providers.company.tr_TR import Provider as TrTrCompanyProvider
 from faker.providers.company.vi_VN import Provider as ViVnCompanyProvider
@@ -45,6 +52,36 @@ class TestAzAz:
             assert company in AzAzCompanyProvider.large_companies
 
 
+class TestDeAt:
+    """Test de_AT company provider methods"""
+
+    def test_company_suffix(self, faker, num_samples):
+        for _ in range(num_samples):
+            suffix = faker.company_suffix()
+            assert isinstance(suffix, str)
+            assert suffix in DeAtCompanyProvider.company_suffixes
+
+    def test_company(self, faker, num_samples):
+        for _ in range(num_samples):
+            company = faker.company()
+            assert isinstance(company, str)
+
+
+class TestDeCh:
+    """Test de_CH company provider methods"""
+
+    def test_company_suffix(self, faker, num_samples):
+        for _ in range(num_samples):
+            suffix = faker.company_suffix()
+            assert isinstance(suffix, str)
+            assert suffix in DeChCompanyProvider.company_suffixes
+
+    def test_company(self, faker, num_samples):
+        for _ in range(num_samples):
+            company = faker.company()
+            assert isinstance(company, str)
+
+
 class TestFiFi:
     """Test fi_FI company provider methods"""
 
@@ -364,6 +401,12 @@ class TestRuRu:
             assert isinstance(bs, str)
             assert bs_words[0] in RuRuCompanyProvider.bsWords[0]
 
+    def test_snils(self, faker, num_samples):
+        for _ in range(num_samples):
+            snils = faker.snils()
+            assert len(snils) == 11
+            assert snils[-2:] == calculate_snils_checksum(snils[:10])
+
 
 class TestItIt:
     """Test it_IT company provider methods"""
@@ -508,3 +551,24 @@ class TestViVn:
         for _ in range(num_samples):
             company = faker.company()
             assert isinstance(company, str)
+
+
+class TestKoKr:
+    """Test ko_KR company provider methods"""
+
+    def test_company_name_word(self, faker, num_samples):
+        for _ in range(num_samples):
+            word = faker.company_name_word()
+            assert isinstance(word, str)
+            assert word in KoKrCompanyProvider.company_name_words
+
+    def test_company_suffix(self, faker, num_samples):
+        for _ in range(num_samples):
+            suffix = faker.company_suffix()
+            assert isinstance(suffix, str)
+            assert suffix in KoKrCompanyProvider.company_suffixes
+
+    def test_company(self, faker, num_samples):
+        for _ in range(num_samples):
+            company = faker.company()
+            assert isinstance(company, str)
